function basisdemo(D,save)
%BASISDEMO  Generates and plots wavelet basisfunctions
%
%  basisdemo(D); basisdemo(D,save)
%
% Creates 1024 unit vectors and performs an inverse wavelet transform
% one all of them. The columns of the resulting matrix Y are plotted 
% to visualize the wavelet basis functions.
% This is done for the wavelet family indicated by D.
%
% If called with two arguments, pictures are saved as eps-files. 
%
% Examples:  basisdemo(4) shows Daubechies 4 bases.
%            basisdemo(4,0) also saves the pictures
	
% Ole Moller Nielsen, UNI-C, 02/27/95.
% Adapted to Matlab 6 by PCH, IMM, April 14, 2001

figure(1);clf
                        
if nargin < 2
  save=0;
  if nargin < 1
    D=4;
  end;  
end;
  	
J0     = 2;          % Coarsest approximation space (J0 >= 0)	
J      = 10;	     % Finest approximation space (J >= J0)	
N      = 2^J;        % Resolution
lambda = J-J0;       % Depth of wavelet transform
Nwave  = 256;         % Number of wavelets          

x = (0:N-1)'/N;      % Abscissae for plots	
X = eye(N);          % Unit vectors
j = J0;              % Initial level
k = 0;               % Initial position
iswavelet = 0;       % indicates wavelets as opposed to scaling fcts


fprintf('This demo displays the first %d periodized basis functions of genus D = %d\n\n', Nwave, D);

fprintf('Periodized scaling functions, j=%d\n',j);
wl=daubfilt(D);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the first Nwave basis vectors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for n=1:Nwave

  if k == 2^j     % Update k and j
    k = 0;
    if iswavelet j=j+1; 
    else         iswavelet=1; 
    end;
    fprintf('Periodized wavelets, j=%d\n',j);    
    pause(1)
  end;     

  figure(1);                        
  bas = ifwt(X(:,n), wl, lambda);        % Compute n'th vector
  plot(x, bas);                          
  set(gca,'XTick',[0 1],'Fontsize',20);  % Tick marks
  set(gca,'Fontsize',16);  
  
    
  if iswavelet
    [S1,errmsg] = sprintf('psi_{%d,%d}(x)',j,k);
    title(['\'  S1],'Fontsize',14)
  else    
    [S1,errmsg] = sprintf('phi_{%d,%d}(x)',j,k);
    title(['\'  S1],'Fontsize',14)
  end
  k = k + 1;
  
  if nargin==2
    eval (['print -depsc2 daub' int2str(D) '_e' int2str(n) '.eps']);
  end;  
  %pause(4/2^j)
  drawnow% , pause(.1)
  
  t0 = clock;
  while etime(clock,t0) < 4/2^j, end;
end


