function [h0,f0] = bfilters(kind)
%
% [h0,f0] = bfilters
%
% Return a set of biorthogonal low-pass filters
%


if nargin < 1 | kind == 0
  % Binary filters from Strang.
  fprintf('Strang binary filters\n')
    h0 = [1  0 -8 16 46 16 -8  0 1]/64;
    f0 = [0 -1  0  9 16  9  0 -1 0]/32;
elseif kind == 1
%Filters from Daubechies p 277
  fprintf('Daubchies 2-2 filters\n')
  h0 = [ 0 1 2 1  0]/4;
  f0 = [-1 2 6 2 -1]/8;
elseif kind == 2 
%Filters from Daubechies p 277
  fprintf('Daubchies 3-1 filters\n')
  h0 = [ 1 3 3  1]/8;
  f0 = [-1 3 3 -1]/4;
elseif kind == 3 
%Filters from Daubechies p 277
  fprintf('Daubchies 3-3 filters\n')
  h0 = [0  0  1  3  3  1  0 0]/8;
  f0 = [3 -9 -7 45 45 -7 -9 3]/64;
end  

%
% Pad with zeros if length is not even
%  
Dh = length(h0);  
if rem(Dh,2) ~= 0
  Dh = Dh+1;
  h0(Dh) = 0;
end   
Df = length(f0);  
if rem(Df,2) ~= 0
  Df = Df+1;
  f0(Df) = 0;
end   


% Always scale and transpose
  h0 = sqrt(2)*h0';
  f0 = sqrt(2)*f0';
