function X = bfwt(X,h,g,levels)
%BFWT2 2D biorthogonal Fast Wavelet Transform.
%
% Xhat = bfwt2(X,h,g,levels)
%
% 2D Discrete Periodized Wavelet Transform of the columns of X.
%
% X:      Matrix        - columns are transformed.
% h,g:  Biorthogonal analysing filters
% levels: Number of splittings (default: inf)
%
% The length of each column of X should be either a power of 2
% at least have a power of 2 as a factor. 

% Ole Moller Nielsen - 16 April 1997.

%%%%%%%%%%%%%%% Parameter check
if nargin < 4
  depth = inf;
  if nargin < 3
    fprintf('ERROR (bfwt): Too few arguments')
    return
  end;
else
  depth = 2^levels;      % Depth of wavelet transform
end;


[N, cols]  = size (X);         % Length of each column

if N < 1 | cols < 1, error('ERROR (fwt.m): Zero length vector specified'); end;
if N < 2, 
  fprintf('WARNING (fwt.m): Length 1 column vector, no transform made'); 
end;

%%%%%%%%%%%%%%% End parameter check

Coarsest_level = max(N/depth, 1);

while rem(N,2) == 0 & N > Coarsest_level;   % Allow for N=2^m*K
  [X,NH] = pwt (X, N, h, g);
  N      = NH;                  % Reduce N to N/2 for next level
end;



