function X = bifwt(X,h,g,levels)
%IFWT Inverse Fast Discrete Periodized Wavelet Transform.
%
%  Y=bifwt (X,h0,f0,levels);
%
% Inverse Discrete Wavelet Transform of the columns of X.
%
% X:      Matrix        - columns are transformed.
% h,g:    Biorthogonal reconstructing filters
% levels: Number of splittings (default: inf)
%
% The length of each column of X should be either a power of 2
% at least have a power of 2 as a factor. 
%

% Ole Moller Nielsen - 16 April 1997.

%%%%%%%%%%%%%%% Parameter check

if nargin < 4
  depth = inf;
  if nargin < 3
    fprintf('ERROR (bfwt): Too few arguments')
    return
  end;
else
  depth = 2^levels;      % Depth of wavelet transform
end;

  
%%%%%%%%%%%%%%% End parameter check

[N, cols]  = size (X);   % N is the length of each column
Coarsest_level = max(N/depth, 1);

FinalN = N;              % Factor N=K*2^m
while rem(N,2)==0,       %Get smallest even N - should be improved
  N=N/2;
end;  
N=max(N, Coarsest_level);
N=2*N;

%N=2;
while N <= FinalN    % Inverse pyramid algorithm starting with finest scale
  [X] = ipwt(X,N,h,g);
  N   = 2*N;
end;




















