% Wavelet Package, Version 2.1.1 2002.
% Copyright (c) 1995 - 2002 by Ole Moller Nielsen
% email: Ole.Nielsen@anu.edu.au
% URL:   http://www.imm.dtu.dk/~omni 
%
% For help on individual functions type 'help <name>'.
%
% Toolbox
%   wavemenu    - Graphical interface for 1D wavelet analysis.
%   wmenu       - Wrapper around wavemenu to allow signals to
%                 be passed as arguments (e.g. wmeny(y)) 
%
%   dst         - Discrete Scaling Function Transform.
%   idst        - Inverse Discrete Scaling Function Transform.
%
%   fwt         - Discrete Wavelet Transform of column vectors.
%   ifwt        - Inverse Discrete Wavelet Transform of column vectors.
%   fwt2        - 2D Discrete Wavelet Transform. (see note below)
%   ifwt2       - 2D Inverse Discrete Wavelet Transform.
%
%   daubfilt    - Daubechies filter coefficients of order D.
%   cascade     - Compute scaling function and wavelet.
%   plotw       - Plot function separated according to scale.
%
%   trunc       - Discard small elements in matrix.  
%
%   difmatrix   - Compute differentiation matrix wrt. scaling functions.
%
% Demos and tests
%   plotbasic   - Plot basic scaling functions and wavelets.
%   basisdemo   - Displays periodized wavelet basis functions.
%   wavecompare - Compares wavelet approximation to Fourier approximation.
%   diftest     - Estimates convergence of the differentiation matrix.
%
%   nlsfft      - FFT split-step solution of the nonlinear Schroedinger eq.
%   burgerfft   - FFT split-step solution of Burgers' equation.
%   nlswofd     - WOFD solution of NLS.
%   burgerwofd  - WOFD solution of Burgers' equation.

%
% Auxiliary routines
%   dstmat      - Get transform matrix between samples and scaling coefs.
%   pwt         - one step of the wavelet transform (columnwise).
%   ipwt        - one step of the inverse wavelet transform (columnwise).
%   mpwt        - one step of the wavelet transform (rowwise).
%   impwt       - one step of the inverse wavelet transform (rowwise).
%   mfwt        - Multiple Discrete Wavelet Transform (used by fwt2).
%   imfwt       - Inverse Multiple Discrete Wavelet Transform (used by ifwt2).
%
%   filttest    - Test filters for all properties.
%   ortho       - Test filters for orthogonality.
%   low2hi      - Computes high pass filter from low pass filter.
%
%   conn        - Compute connection coefficients.
%   moments     - Compute moments of scaling function.
%   tmoments    - Compute translated moments of scaling function.
%
%   makegrid    - Create WOFD grid.
%   fdmat       - Build finite difference matrices.
%   updfdmat    - Update finite difference matrices.
%
%   fac         - factorial.
%   binom       - binomial coefficient.
%   search      - binary search.
%   pmod        - modulus function. 

%NOTE the 2d transforms rely on mfwt and imfwt which 
%can be sped up by using their MEX file versions.
%
% Compile the MEX source files mfwt.c and imfwt.c once on each platform
% by calling
%
% >> mex mfwt.c; mex imfwt.c
%
% The resulting MEX files will override the standard m-files
% and speed up the 2d transforms considerably.

