function c=dst(f, Wavelet)
%DST   Discrete Scaling-function Transform.
%
%  c = dst(f, D)
%
%  Input
%    f:  Matrix, where columns are the vectors to be transformed.
%    D:  Wavelet genus - optional, default D=4.
%
%  Output
%    c:  Matrix, where columns are the scaling function coefficients
%        corresponding to f
%
%
%  See also idst, dstmat, fwt, ifwt.

% Ole Moller Nielsen, September 1996.


%%%%%%%%%%%%%%% Parameter check

if nargin < 2
  Wavelet = daubfilt(4); % Default filters 
end;  
  
len = length(Wavelet);  % Determine the nature of argument #2:
if len > 1
  D  = len;
  lp = Wavelet;         % First argument is a wavelet filter
else
  D  = Wavelet;
  lp = daubfilt(D);     % First argument is the wavelet genus
end;    

[N,cols] = size(f);
if N == 0
  fprintf('ERROR (dst.m): Null vector f\n');
  c = [];
  return;
end;  
[rows, cols] = size(f);
if rows == 1
  fprintf('ERROR (dst.m): f is a row vector - no transform made\n');
  c = [];  
  return;
end;  

%%%%%%%%%%%%%%% End parameter check


L = N;              % Factor N=K*2^m
while rem(L,2)==0,  
  L = L/2;
end;  
r = log2(N/L);      % Get resolution of f

j=r;    %Get as many coefficients as samples.
q=r-j;  %Get sufficient resolution for phi

T = dstmat(D,r,j,q,L);

c = T\f;               %Solve f=T*c for c. 
%c = T'*f;              %Approximate  c = \int f(x) phi(x) dx. 




