function [Dx,Dxx]=fdmat(x,L,p,replace)
%FDMAT  Compute first and second order finite difference matrices
%
%  [Dx,Dxx]=fdmat(x,L,p,replace)
%
%  Input
%    x: Abscissae - need not be equidistant
%    L: Length of domain.
%    p: Stencil: p=3 is second order (default), 
%                p=5 is fourth order etc
%    replace:    Logical vector. 
%                1 means that row at that position must be computed
%
% See also updfdmat, burgerwofd, nlswofd.

% OMN, May 1997


sh = 1;         % Address vectors and matrices from 0 to N-1 using sh
N  = length(x);

equi = 0;
if nargin < 4
  replace = zeros(N,1);   % Compute operator on equidistant grid
  replace(1) = 1; 
  equi = 1;

% Insert test for equidistant x !!!!!!!

 
 if nargin < 3
    p=3;
  end;
end;    



if N <= p-2 
  fprintf('ERROR (fdmat.m): Stencil exceeds vector.\n')
  Dx=0; Dxx=0;
  return
end   

if length(replace) ~= N
  fprintf('ERROR (fdmat.m): Index vector exceeds data vector.\n')
  Dx=0; Dxx=0;
  return
end;

  compute = replace;

  f0 = flops;
  cpu0 = cputime;
  
  w = (p-1)/2;     
  
  d=spalloc(N,N,p*N);
  n1 = d;
  n2 = d;
  Dxx = d;
  Dx  = d;
  
  p1 = p-1;
  w=(p1)/2;

  xaug = [x(N-(p-2):N)-L;x;x(1:p-2)+L]; %Augment domain according to stencil
  %fprintf('Init: flops = %d\n',flops-f0);  
  %fprintf('Init: time  = %8.2f\n',cputime-cpu0);

  % Precompute all relevant differences
  dif = spalloc(N+2*p1,N+2*p1,2*p*N);
  for i=0:N-1
    if (compute(i+sh))  
      ii = i+p1+sh;        
      for k=i-w:i+w
        kk = k+p1+sh;
        for l=i-w:i+w
          if l ~= k
            ll = l+p1+sh;
	    if ~dif(kk,ll) 
              dif(kk,ll) = xaug(kk) - xaug(ll);
	    end
	  end;
        end;	  
      end;
    end; 
  end;
  %dif=sparse(dif);  
  %fprintf('Differences: flops = %d\n',flops-f0);  
  %fprintf('Differences: time  = %8.2f\n',cputime-cpu0);

  for i=0:N-1
    row = i+sh;
    if (compute(row))    
      ii = i+p1+sh;    
         
      if dif(ii,ii-w:ii+w) == dif(ii-1,ii-1-w:ii-1+w)
        %fprintf('Reusing %d\n',i+sh);
        % Use values from previous row (could be generalized to any row)
        for k=i-w:i+w
          %col =pmod(k,N)+sh;
          col = k+sh;
          if col>N, col=col-N; end;
          if col<1, col=col+N; end;

          %col1=pmod(k-1,N)+sh;  % Corresp col in prev row
          col1 = k-1+sh;
          if col1>N, col1=col1-N; end;
          if col1<1, col1=col1+N; end;

          Dx(row,col)  = Dx(row-1,col1); 
          Dxx(row,col) = Dxx(row-1,col1);
        end 
%        fprintf('Replicate: ')
%        [32*x(row) full(Dxx(row,:))]
      else
        % Compute values:
 
      for k=i-w:i+w
        %col=pmod(k,N)+sh;
        col = k+sh;
        if col>N, col=col-N; end;
        if col<1, col=col+N; end;

        kk = k+p1+sh;
       
        %f1=flops;
        % Compute denominators d_ik:
        %
        tmp = 1;      
        for l=i-w:i+w
          if l ~= k
            ll = l+p1+sh;
            tmp = tmp*dif(kk,ll);   % (x_k-x_l) 	  
          end;
        end;
        d(row,col)=tmp;
      
        %fprintf('Denoms: flops = %d\n',flops-f1);  
        %f1 = flops;
        % Compute first order nominators n1_ik:
        %
        sum = 0;      
        for l=i-w:i+w
          if l ~= k
            tmp=1;
            for m=i-w:i+w
              if (m ~= l & m ~= k)   
                mm = m+p1+sh;	      
                tmp = tmp*dif(ii,mm);  % (x_i-x_m)
              end;
            end;
            sum = sum + tmp; 
          end;
        end;
        n1(row,col)=sum;

        %fprintf('1st order: flops = %d\n',flops-f1);  
        %f1=flops;
        % Compute second order nominators n2_ik:
        %
        sum = 0;
        for l=i-w:i+w
          if l ~= k
            for m=i-w:i+w
              if (m ~= l & m ~= k)   
                tmp = 1;
                for n=i-w:i+w
                  if (n~=m & n~=l & n~=k)
		    nn = n+p1+sh;
                    tmp = tmp*dif(ii,nn);  % (x_i-x_n)		  
                  end;  
                end;
                sum = sum + tmp;
              end;
            end;
          end;
        end;
        n2(row,col)=sum;

        %fprintf('2nd order: flops = %d\n',flops-f1);  
        %f1=flops;
        % Compute operators
        %      
        Dx(row,col)  = n1(row,col)/d(row,col);
        Dxx(row,col) = n2(row,col)/d(row,col); 
        %fprintf('Ops: flops = %d\n',flops-f1);  
        %f1=flops;
      end;
      end; % If previous row the same
    end;   % If compute
  end;   % For all rows

  cpu1=cputime;
  f1  = flops;
  if equi        % Replicate row i=0 to the rest
    for i=1:N-1  % Skip i=0 
      row = i+sh;
      for k=[0:w, N-w:N-1]       % k= -w:w  mod N
        refcol = k+sh;           % Column in row 0
%        col = rem(k+i,N)+sh;    % Column in row i
        col=k+i+sh;              % More flops but faster
        if col>N, col=col-N; end;
               
        Dxx(row,col) = Dxx(1,refcol); % Reuse elements from row 1
        Dx(row,col)  = Dx(1,refcol);  % Reuse elements from row 1
      end;
    end;
  end
  %fprintf('equi: flops = %d\n',flops-f1);
  %fprintf('equi: time  = %8.2f\n',cputime-cpu1);    

  %fprintf('Finished: flops = %d\n',flops-f0);  
  %fprintf('Finished: time  = %8.2f\n',cputime-cpu0);   

