function err = filttest(lp)
%
%  err=filttest(lp) returns a number which reflects how well the 
%  coefficients in lp satisfy orthogonality (using ortho.m), 
%  conservation of area and the property of vanishing moments.
%
%  See also daubfilt, low2hi, ortho.

% OMN - 1997  

  D = length(lp);

  P = D/2;  % Number of vanishing moments
  N = P-1;  % Dimension of nullspace of the matrix A
  R = P+1;  % Rank of A, R = D-N = P+1 equations

  err = 0;  
  
  %
  % Check orthogonality  
  %
  for k=0:N          
    o = ortho(k,lp);              
    if k==0 o = 1-o; end
    err = err + abs(o);
  end  
 
  %
  % Check dilation equation (conservation of area)
  %
  err = err + abs(sum(lp)-sqrt(2));
  
  
  %
  % Check vanishing moments 
  %
  % Condition number of A grows with P, so we test only
  % the first 6
  %
  A    = zeros(R,D);      % D unknowns, D-N equations
  b    = zeros(R,1);      % Right hand side
  b(1) = sqrt(2);                
  
  A(1,:) = ones(1,D); % Coefficients must sum to sqrt(2)
  for p=1:min(P,6)    % the p'th vanishing moment (Cond Ap) 
    for k=1:D            
      m=D-k+1;
      A(p+1,k) = (-1)^m * (k-1)^(p-1);
    end;
  end;

  err = err + norm(b-A*lp);








