function X = fwt(X,Wavelet,depth)
%FWT Fast Discrete Periodized Wavelet Transform.
%
%  X = fwt(X,D,lambda)
%
%  Input
%    X:      Matrix, where columns are the vectors to be transformed.
%    D:      Wavelet genus - optional, default D=4.
%    lambda: Depth of the transform - optional.
%            Default is largest possible depth.            
%
%  Output
%    X:  Matrix, where columns are the transformed vectors.
%
%  The number of rows in X should have a power of 2 as a factor. 
%
%  See also ifwt, dst, idst.

% Ole Moller Nielsen - 21 July 1995.

%%%%%%%%%%%%%%% Parameter check
if nargin < 3
  depth = inf;
  if nargin < 2
    Wavelet = daubfilt(4); % Default filters 
  end;
end;

len = length(Wavelet);  % Determine the nature of argument #2:
if len > 1
  D  = len;
  lp = Wavelet;       % First argument is the wavelet filter (from daubfilt.m)
  hp = low2hi(lp);      
else
  D  = Wavelet;       % First argument is the wavelet genus
  [lp, hp] = daubfilt(D);   
end;
%wl = [lp;hp];         % Aggregate filters in one vector 

[N, cols]  = size (X);   % N is Length of each column

if N < 1 | cols < 1, 
  fprintf('ERROR (fwt.m): Zero length vector specified'); 
  X = [];
  return
end;

if N < 2, 
  fprintf('WARNING (fwt.m): Length 1 column vector, no transform made'); 
end;
  
  
%%%%%%%%%%%%%%% End parameter check

Coarsest_level = max(N/2^depth, 1);

while rem(N,2) == 0 & N > Coarsest_level;   % Allow for N=2^m*K
  [X,NH] = pwt (X, N, lp, hp);
  N      = NH;                   % Reduce N to N/2 for next level
end;







