function X = fwt2(X, Wavelet, lambda)
%FWT2  2D Fast Discrete Wavelet Transform (non standard form).
%
%  X = fwt2ns(X, D, lambda)
%
%  Input
%    X:       Matrix, where columns are the vectors to be transformed.
%    D:       Wavelet genus - optional, default D=4.
%    lambda:  Depth of the transform in both dimensions - optional.
%             Default is largest possible depth.            
%
%  Output
%    X:  Matrix, where columns and rows have been transformed.
%
%  If the number of rows and columns does not have a power of 2 as factor
%  no transform is made.
%
%  See also ifwt2ns, fwt2, ifwt2, fwt, ifwt, dst, idst.

% Ole Moller Nielsen - 19 April 1999.


%%%%%%%%%%%%%%% Parameter check

if nargin < 3
  lambda = inf;
  if nargin < 2
    Wavelet = daubfilt(4); % Default filters 
  end;
end;
  
len = length(Wavelet);  % Determine the nature of argument #2:
if len > 1
  D  = len;
  lp = Wavelet;    % First argument is the wavelet filter (from daubfilt.m)
else
  D  = Wavelet;
  lp = daubfilt(D);      % First argument is the wavelet genus
end;    
%%%%%%%%%%%%%%% End parameter check

[M,N] = size(X);

for j=0:lambda-1
  Mvec = 1:M/2^j;
  Nvec = 1:N/2^j;  
  X(Mvec,Nvec) = fwt2(X(Mvec,Nvec), D, 1, 1);  % One level of standard FWT2 
end;













