function X = ifwt(X, Wavelet,depth)
%IFWT Inverse Fast Discrete Periodized Wavelet Transform.
%
%  X = ifwt(X,D,lambda)
%
%  Input
%    X:      Matrix, where columns are the vectors to be transformed.
%    D:      Wavelet genus - optional, default D=4.
%    lambda: Depth of the transform - optional.
%            Default is largest possible depth.            
%
%  Output
%    X:  Matrix, where columns are the transformed vectors
%
%  The number of rows in X should have a power of 2 as a factor. 
%
%  See also fwt, dst, idst.

% Ole Moller Nielsen - 21 July 1995.


% Example: 
%   Y=ifwt (eye(n));
% gives n wavelet bases as the columns in Y 

%%%%%%%%%%%%%%% Parameter check
if nargin < 3
  depth = inf;
  if nargin < 2
    Wavelet = daubfilt(4); % Default filters 
  end;
end;
  
len = length(Wavelet);  % Determine the nature of argument #2:
if len > 1
  D  = len;
  lp = Wavelet;       % First argument is the wavelet filter (from daubfilt.m)
  hp = low2hi(lp);      
else
  D  = Wavelet;       % First argument is the wavelet genus
  [lp, hp] = daubfilt(D);   
end;
%wl = [lp;hp];         % Aggregate filters in one vector 

[N, cols]  = size (X);   % N is the length of each column

if N < 1 | cols < 1, 
  fprintf('ERROR (ifwt.m): Zero length vector specified'); 
  X = [];
  return
end;

if N < 2, 
  fprintf('WARNING (ifwt.m): Length 1 column vector, no transform made'); 
end;


%%%%%%%%%%%%%%% End parameter check


Coarsest_level = max(N/2^depth, 1);

FinalN = N;              % Factor N=K*2^m
while rem(N,2)==0,       % Get smallest even N
  N=N/2;
end;  
N=max(N, Coarsest_level);
N=2*N;

%N=2;
while N <= FinalN    % Inverse pyramid algorithm starting with finest scale
  [X] = ipwt(X,N,lp,hp);
  N   = 2*N;
end;




















