function X = ifwt2(X, Wavelet, lambdaM, lambdaN)
%IFWT2  2D Inverse Fast Discrete Wavelet Transform.
%
%  X = ifwt2(Y, D, lambdaM, lambdaN)
%
%  Input
%    X:       Matrix to be transformed.
%    D:       Wavelet genus - optional, default D=4.
%    lambdaM: Depth of the transform in the first dimension - optional.
%             Default is largest possible depth.            
%    lambdaN: Depth of the transform in the second dimension - optional.
%             Default is largest possible depth.            
%
%  Output
%    X=(W^T*Y*W)^T: Transformed matrix transposed.
%
%  If the number of rows or columns does not have a power of 2 as factor
%  no transform is made.
%
%  See also fwt2, fwt, ifwt, dst, idst.

% Ole Moller Nielsen - 10 September 1995.


%%%%%%%%%%%%%%% Parameter check
if nargin < 4
  lambdaN = inf;
  if nargin < 3
    lambdaM = inf;
    if nargin < 2
      Wavelet = daubfilt(4); % Default filters 
    end;
  end;
end;
  
len = length(Wavelet);  % Determine the nature of argument #2:
if len > 1
  D  = len;
  lp = Wavelet;    % First argument is the wavelet filter (from daubfilt.m)
  hp = low2hi(lp);          
else
  D  = Wavelet;
  [lp, hp] = daubfilt(D);      % First argument is the wavelet genus
end;    
%%%%%%%%%%%%%%% End parameter check

W = X;               %Rename X
if exist('imfwt')==3 %If we are using the MEX version of imfwt
  W(1,1)=X(1,1);     %Make it a actual copy (imfwt.c destroys input matrix)
  if issparse(W),
    W = full(W);
  end;					     
end;

X = imfwt(W, lambdaM, lp, hp);  % Transform columns
X = X'; 
X = imfwt(X, lambdaN, lp, hp);  % Transform rows


















