function [X] = impwt(X, N, lp, hp)
%IPWT Inverse Partial (Single stage) Wavelet Transform.
%
%  X = impwt (X, N, lp, hp);
%
%
%  Input
%    X:      Matrix, where rows are the vectors to be transformed.
%    N:      Length of transform.
%    lp:     Low pass filter    
%    hp:     High pass filter (e.g. [lp,hp] = daubfilt(8))
%
%  Output
%    X:  Matrix, where rows are the transformed vectors.
% 
%  Performs one step of the inverse wavelet transform 
%  on the first N components of each row of X.
%
% See also mfwt, imfwt, and mpwt

% Ole Moller Nielsen - 1998.

% The algorithm is formulated as vector operations to
% increase efficiency.

D   = length (lp);
if D ~= length(hp);
  fprintf('ERROR (mpwt): Filters should be of same length. Pad shortest one with zeros.');
end;

%D   = length (wl)/2; % Wavelet genus
%lp  = wl(1:D);       % Low pass filter
%hp  = wl(D+1:2*D);   % High pass filter

NH  = N/2;

T  = zeros (size(X));  % Workspace

mul = ceil((D-2)/2/NH);
NH_multiple = mul * NH;     % Nearest multiple of NH gt (k-i)/2 forall k,i


for i = 1:2:N   
  for k = 1:2:D        
    k1 = k+1;           

    i1 = i+1;
    j  = (i-k)/2;
    r  = rem(NH_multiple + j, NH) + 1;

    T(:,i)  = T(:,i)  + lp(k) *X(:,r) + hp(k) *X(:,r+NH);
    T(:,i1) = T(:,i1) + lp(k1)*X(:,r) + hp(k1)*X(:,r+NH);          
  end;
end;         

X(:,1:N) = T(:,1:N);  % Copy inverse wavelet transform at level N back into X
clear T;






