function [X] = bipwt(X, N, lp, hp)

%IPWT Inverse Partial (Single stage) Wavelet Transform.
%
%  X = bipwt (X, N, lp, hp);
%
% Perform one step of the inverse wavelet transform.
%
% See also: DAUB, FWT, IFWT, and PWT
%
% Ole Moller Nielsen - 16 April 1997.


D   = length (lp);
if D ~= length(hp);
  fprintf('ERROR (pwt): Filters should be of same length. Pad shortest one with zeros.');
end;

T   = zeros (size(X));  % Workspace

NH  = N/2;

mul = ceil((D-2)/2/NH);
NH_multiple = mul * NH;     % Nearest multiple of NH gt (k-i)/2 forall k,i

for k=1:2:D        
  if k > N+1,      % Determine which part must be computed with modulus (rem)
    crossover = N;
  else
    crossover = k-1;
  end; 
        
  k1 = k+1;           
        
  % ---- Modulus phase  - only a fraction of the total time is spent here     
  j = (1-k)/2-1;
  for i = 1:2:crossover   
    i1 = i+1;
    j  = j+1;                           % j = (i-k)/2
    r  = rem(NH_multiple + j, NH) + 1;

    T(i,:)  = T(i,:)  + lp(k) *X(r,:) + hp(k) *X(r+NH,:);
    T(i1,:) = T(i1,:) + lp(k1)*X(r,:) + hp(k1)*X(r+NH,:);          
  end;
         
         
  % ------------ Linear phase -----------------
  L           = (N-crossover)/2;
  if L > 0
    B1          = crossover + 1;
    B2          = crossover + 2;
    NH1         = NH+1;
    NHL         = NH+L;
    Xsub1       = X(1:L,:);
    Xsub2       = X(NH1:NHL,:);
    T(B1:2:N,:) = T(B1:2:N,:) + lp(k) *Xsub1 + hp(k) *Xsub2;
    T(B2:2:N,:) = T(B2:2:N,:) + lp(k1)*Xsub1 + hp(k1)*Xsub2;
    clear Xsub1;
    clear Xsub2;
  end;
end;

X(1:N,:) = T(1:N,:);  % Copy inverse wavelet transform at level N back into X
clear T;








