function [indices]=makegrid(f,D,epsilon)
%MAKEGRID  Create WOFD grid
%
%  indices=makegrid(f,D,epsilon)
%
%  Input
%    f: Function values
%    D: Wavelet genus (Default = 4)
%    epsilon: tolerance
%
%  Output
%    indices: Vector cosisting of 0 and 1 defining new grid
%
% See also fdmat, updfdmat, burgerwofd, nlswofd
%

% Ole Moller Nielsen, May - 97.
f0 = flops;

sh = 1; % Index vectors with zero
%epsilon = 1.0e-4;

usedst = 1;  %Use dst transform before fwt and vice versa
%usedst = 0;  %Don't use dst transform.

%%%%%%% Parameter check
N   = length(f);       
J   = log(N)/log(2);   % There are N=2^J coefficients	
if N ~= 2^J, abort('makegrid', 'Length must be a power of 2'); end;

lambda = 6;    % This is the DEPTH of the wavelet splitting

NH  = N/2;    
M   = lambda+1;             % Noof rows in hierarchy matrix

%x1  = x(1:2:N);        % fhat at finest level has length NH

[rows,cols] = size(f);
if (N == cols) f = f'; end;   %fhat must be a column vector;

wl   = daubfilt(D);
if usedst
  c  = dst(f,wl);
else  
  c  = f;   % Shortcut  
end;  

%fprintf('init in makegrid = %d\n',flops-f0);
%f0=flops;

fhat = fwt(c,wl,lambda);
%fprintf('fwt in makegrid = %d\n',flops-f0);
%f0=flops;

maxco = max(abs(fhat));
tolerance = maxco*epsilon;

%%%% Construct index for non-uniform grid corresp to f

%indices = ones(N,1);  % All points included initially
indices = zeros(N,1);  % All points excluded initially

P   = zeros(M,N); % row one is finest level, row M-1 is coarsest and 
                  % row M is scaling coefficient at coarsest level (DC). 

% Take one level at a time (starting at the finest) 		  
%factor = 1;
last  = N;
j = J-1;           % Finest level

for p = M-1:-1:1   % Don't include DC term (p=0)
  first  = last/2;
  factor = 2^(J-j);
  
%  if p > 0
    coefs = fhat(first+1:last);
%  else
%    coefs = fhat(1:last);  % DC-term     
%  end; 
  
% Remove points
%  for k=0:length(coefs)-1
%    if abs(coefs(k+sh)) < tolerance
%  %    i = (k+0.5)*factor;
%  %      midpoint = (D-1)/2;
%      midpoint = 0.5;
%      i = pmod( (k+midpoint)*factor, N);%
%
%      indices(i+sh)  = 0;
%    end
%  end

% Introduce necessary points
  tol = tolerance * 2^(-3*j/2);
  tol = tolerance;
%  tol = tolerance * 2^(-j*(D+1)/2) / fac(D/2);
%  disp([j, tol])
  
  for k=0:length(coefs)-1
    if abs(coefs(k+sh)) >= tol
      % Introduce points in the support of this coefficient    
%      for l=0:2*D-2    % The support exactly
      for l=-3:2*D-1   % Nice choice for Burgers equation
        ind = (k + l/2)*factor;
        i = pmod(ind, N);
        indices(i+sh)  = 1; %ones(size(i));
      end;	
    end;
  end;

  last = first;
  j = j-1;
end 

% DC term

for k=1:factor:N
  indices(k)=1;
end;    

%fprintf('3 in makegrid = %d\n',flops-f0);
%f0=flops;  



