function Mom = moments (lp, pmax);
%MOMENTS  Compute moments of scaling function 
%
%  Mom = moments (lp, pmax); 
%
%  Input:
%    lp:   Filter coefficients (e.g. obtained from daubfilt)
%    pmax: Number of moments to be computed
%
%  Output:
%    Mom:  Vector of moments from 1 to pmax
%
% Use transmoments.m to obtain moments of translated scaling function
%
% The zeroth moment is always 1 and is therefore not stored
%
% See also transmoments, conn.

% OMN 1996

N = length (lp);

M0  = 1;
Mom = zeros (1, pmax);

for p = 1:pmax
  fact = sqrt(2)/2/(2^p-1);  
  for k = 0:p-1
    if k==0 
      Mk = M0;
    else
      Mk = Mom(k);
    end;  
    
    dM = 0;              %"Discrete moment"
    for i=0:N-1
      dM = dM + lp(i+1) * i^(p-k);
    end;
    
    bin    = binom (p,k);
    Mom(p) = bin * Mk * dM;
  end
  Mom(p)=fact*Mom(p);  
end




