function s=ortho(n,v,w) 
%ORTHO  Test orthogonality condition of filter coefficients.
%
%  s=ortho(n,v,w) 
%  Computes s = \sum_i v(i)*w(i+2n)  
%
%  s=ortho(n,v) 
%  Computes s = \sum_i v(i)*v(i+2n)  
%
%
%  Ex: ortho(1,v):   s = v(1)*v(3) + v(2)*v(4) + ...
%
%      ortho(1,v,w): s = v(1)*w(3) + v(2)*w(4) + ... +
%                        w(1)*v(3) + w(2)*v(4) + ...
%
%  See also daubfilt, filttest.

% Ole Moller Nielsen, NYU, 03/18/96.

k = 2*n;

Dv = length(v);
if nargin > 2
  Dw = length(w);
else
  Dw = 0;
end;    

D = max(Dv,Dw);
dif = abs(Dw-Dv);

if dif > 0
  if Dw > Dv
    v(Dv+1:Dw) = zeros(dif,1);
  else 
    w(Dw+1:Dv) = zeros(dif,1);
  end
end
  
s = 0;
if nargin==2
  for i=1:D-k
    s = s + v(i)*v(i+k);
  end;
else  
  for i=1:D-k
    s = s + v(i)*w(i+k) + w(i)*v(i+k);
  end;
  s = s/2;
end;
 
