function plotbasic(sav)
%PLOTBASIC  Plot basic scaling functions and wavelets 
%           for D=2,4,...,50
%
%  plotbasic    plots to screen
%  plotbasic(1) plots to screen and saves graphs in eps-files

% OMN 1998
% Adapted to Matlab 6 by PCH, IMM, April 14, 2001

if nargin < 1
  sav = 0;  % Save to disk
end

if sav 
  q = 8;   % Resolution 
else
  q = 7;
end;    

fs  = 18;       % Fontsize for plots	
fct = 0.96;     % Adjust for Matlab error at boundary !
sq2 = sqrt(2);

%%%%%%%%%%%%%%%%%%
% Position figures
%%%%%%%%%%%%%%%%%%
H1 = figure(1);clf;
set (H1,'Position',[30 420 500 400]);
H2 = figure(2);clf;
set (H2,'Position',[540 420 500 400]);  

%%%%%%%%%%%%%
% Loop over D
%%%%%%%%%%%%%
for D=2:2:50,
%for D=[4 6 10 20 40],
  name = ['D' int2str(D)];    
  [x,phi,psi]=cascade(D,q);

  figure(1)
  plot(x,phi);
  title(['\phi,    D = ' num2str(D)],'Fontsize',[fs])  
  if sav  
    set(gca,'Fontsize',[fs]);    
    H    = get(gca);
    tit  = get(H.Title);
    tit.Position(2) = fct*tit.Position(2);
    set(H.Title,'Position',tit.Position);

    eval(['print -deps phi' name '.eps']);    
  else  
    axis([0 50 -0.5 sq2])
  end;  

  figure(2);
  plot(x,psi);
  title(['\psi,    D = ' num2str(D)],'Fontsize',[fs])  
  if sav
    set(gca,'Fontsize',[fs]);    
    H    = get(gca);
    tit  = get(H.Title);
    tit.Position(2) = fct*tit.Position(2);
    set(H.Title,'Position',tit.Position);
  
    if D==20 | D==40
      set(gca,'Ytick',[-0.6 -0.3 0 0.3 0.6]); 
    end
    eval(['print -deps psi' name '.eps']);    
  else  
    axis([0 50 -1 sq2]);
  end;
  
  drawnow, pause(0.4)
end;





