function ploth(x,fhat)
%
% ploth(x,fhat)  or  ploth(fhat)
%
% Plots dyadic subdivisions of fhat hierarchically.
%
% fhat could for example be the wavelet spectrum obtained from fwt.m
%
% Ole Moller Nielsen, DTU, October - 96.

%usesubplot = 1;
usesubplot = 0;

spikes = 1; % Plot coarser levels as spikes (recommended)
%spikes = 0; % Plot coarser levels as boxes (easily confused with Haar)

normalize = 1; % Normalize each scale separately (Best for ploth)
%normalize = 0; % Show true amplitudes

%%%%%%% Parameter check
N   = length(x);       % NB x is fhat if called with only one argument!
p   = log(N)/log(2);   % There are N=2^p coefficients	
if N ~= 2^p, abort('ploth', 'Length must be a power of 2'); end;

NH  = N/2;    
M   = p+1;             % Noof rows in hierarchy matrix

if nargin < 2
  fhat = x;            % Plot only fhat
  x    = (1:NH);       % x is then just the indices in fhat.
else
  x = x(1:2:N);        % fhat at finest level has length NH
end;

[rows,cols] = size(fhat);
if (N == rows) fhat = fhat'; end;   %fhat must be a row vector;

%%%%%%% Construct hierarchical matrix

P   = zeros(M,NH); % row one is finest level, row M-1 is coarsest and 
                   % row M is scaling coefficient at coarsest level (DC). 

if spikes                                   % Spike representation
  first = NH+1;
  last  = N;
  skip  = 1;
  shift = 0;
  
  for j = 1:M-1 
    P(j,1+shift:skip:NH) = fhat(first:last);
    shift = 2^((j+1)-2);
    skip  = skip*2; 
    last  = first-1;
    first = last/2 + 1;
  end;
  shift = 2^(p-2);
  P(M,1+shift:NH:NH) = fhat(1:1);
else                                            % Box representation
  len   = NH;    % Noof coef at each level
  width = 1;     % "Support" of each coefficient
  for j = 1:M-1 
    block = ones(1,width);
    for k = 0:len-1
      first = k*width+1;
      last  = (k+1)*width;
      P(j,first:last) = fhat(len+1+k) * block;
    end;    
    width = width*2; 
    len   = len/2;
  end;
  P(M,:) = fhat(1:1)*ones(1,NH); % DC term
end;

%%%%%%%%%%%% Plot
if normalize
  graphname = ['Hierarchy of wavelet coefficients (normalized)'];
else 
  graphname = ['Hierarchy of wavelet coefficients'];
end;
    
clf
if usesubplot
  for j=1:M
    subplot(M,1,j);
    plot(x,P(j,:));    	    
    level = M-j-1;
    if level < 0
      ylabel('p=0 (sc)');
    else
      ylabel(['p=' int2str(M-j-1)]);
    end;
  end;
  title(graphname);
else
  hold on

  scales = zeros(M,1);  
  if normalize
    for j = 1:M
      scales(j) = max(abs(P(j,:)))*2.1; % Maximal amplitude (+ some slack)
    end;
    offset = 1;
  else
    scales = ones(M,1);                 % No scaling  
    offset = ceil(max(max(abs(P))));
    while rem(offset,5) ~= 0, offset = offset + 1; end;
  end;    

  Psc = zeros(size(P));
%  fprintf('=============Ignore the following warnings:');
  for j = 1:M
%    mask = 1./(abs(P(j,:)) > 0);    % Identify non-zeros, let zeros be NaN
    mask = ones(size(P(j,:)));
    if scales(j) ~= 0,
      Psc(j,:) = mask.*P(j,:)/scales(j);  % Normalize each level:
    end;  
  end;
%  fprintf('=============End of warnings\n');  
  
  xpos   = ceil(x(NH))+0.05*x(NH);
  Pud    = flipud(Psc);
  scales = flipud(scales);
  
  for j=1:M
    ypos = (j-1)*offset;
%    plot(x,Pud(j,:) + ypos,'*',x,zeros(size(x))+ypos,':');    	    
    plot(x,Pud(j,:) + ypos,'-');    	    
%    bar(x,Pud(j,:) + ypos);    	    
%   pause
   
    str = ['(*' int2str(ceil(scales(j))) ')'];
%    level = j-2;        
%    if level < 0, levstr = [str ', (sc)'];
%    else          levstr = [str ', p=' int2str(level)];
%    end;
    levstr = str;

    text(xpos,ypos+0.2,[levstr])
  end;
  set(gca,'Ytick',[])
  set(gca,'Xtick',[])  
  title(graphname);  
end;







