function [yfwt2, P] = plotw2(X1,X2,A,D,lambda,extension)
%
%  [yfwt2, P] = plotw2(A,D,lambda,extension);
%
% Separate matrix A into single-scale components
% based on a 2D wavelet transform using Daubechies wavelets
% with genus D.
%
% lambda is the transform depth
%
% OMN 1999

ns = 0;  %ns = 0: Standard form,  ns = 1: Nonstandard form

[M0,N0]=size(A);   %Assume M=N for now

[xe,Aee]=extend2(X1,X2,A,D,lambda,extension);
	
[M,N]=size(Aee);
A = Aee;	
	
if ns	
  WA = fwt2ns(A,D,lambda);
else
  WA = fwt2(A,D,lambda,lambda);
end; 

ratio = 0;
[WA,ratio] = trunc(WA,eps);
fprintf('Pct discarded %6.2f (below machine precision %e)\n',ratio*100,eps);
WA = sparse(WA);
yfwt2 = WA;     %Includes extension

%
% Partion into different resolutions
%
lastM  = M; lastM0  = M0;
lastN  = N; lastN0  = N0;
for j = 1:lambda 
  firstM  = lastM/2;  firstN  = lastN/2;  
  firstM0 = lastM0/2; firstN0 = lastN0/2;
  
  lpM = 1:firstM; hpM = firstM+1:lastM;
  lpN = 1:firstN; hpN = firstN+1:lastN;
  
  WA00 = WA(lpM,lpN); Z00 = zeros(size(WA00));
  WA01 = WA(lpM,hpN); Z01 = zeros(size(WA01));
  WA10 = WA(hpM,lpN); Z10 = zeros(size(WA10));
  WA11 = WA(hpM,hpN); Z11 = zeros(size(WA11));

  WA1 = zeros(M,N);  % Matrix containing coefficients at level j
  %WA1 = spalloc(M,N,nnz(WA01) + nnz(WA10) + nnz(WA11)); %Not faster
      
  WA1(lpM,hpN) = WA01;  
  WA1(hpM,lpN) = WA10;  
  WA1(hpM,hpN) = WA11;  
  

  %  %Remove zeros from plots
  %  warning off
  %  DT = WA1 + log(WA1 ~= 0);
  %  warning on
  %  figure(20);subplot(lambda,1,j); mesh(DT); drawnow;

  
  if ns  
    HF = ifwt2ns(WA1,D,lambda); %All details
  else  
    HF = ifwt2(WA1,D,lambda,lambda); %All details
  end;  
  HF = HF(1:M0,1:N0);
  
  P{j} = HF; 
  
  lastM = firstM;
  lastN = firstN;  
end;  		

WA1 = zeros(M,N);  % Matrix containing coefficients at level j
WA1(lpM,lpN) = WA00;

%yfwt2(lpM0,lpN0) = WA(lpM0,lpN0);

if ns
  LF = ifwt2ns(WA1,D,lambda); %Coarsest approx  
else  
  LF = ifwt2(WA1,D,lambda,lambda); %Coarsest approx  
end;  
LF = LF(1:M0,1:N0);
P{lambda+1} = LF;

%
% Plot
%
nographs = lambda+1+1;
H=figure(gcf); clf; grid off; graphdim = ceil(sqrt(nographs));
for j=1:nographs
  if j == nographs            %Original image
    TMP = A(1:M0,1:N0); 
  else                        %Wavelet decomposition
    TMP = trunc(P{j},1.0e-3); %Remove small elements from detail plots
    if j <= lambda
      warning off
      TMP = TMP + log(TMP ~= 0);
      warning on
    end;
  end;    
  set(0,'CurrentFigure',H); subplot(graphdim, graphdim, j); 
  mesh(X1, X2, TMP); view(2);
end;

return





