function i = search(table, key, tol)
%SEARCH - binary search
%
%   i = search(table, key, tol)
%
% Find index for first occurrence of key in the table 
% within tolerance tol.
% If tol is omitted, tol = 0.
%
% Only the leading dimension of table is visited, and
% it must be sorted numerically in ascending order.
%
% If key doesn't belong to the table within the given tolerance, 
% a value of length(table)+1 is returned 
%

% OMN, ANU - Oct 1995

if nargin < 3
  tol = 0;
end;
  
N     = length(table);
left  = 1;
right = N;

found = 0;
while ~found & right >= left   % Perform binary search
  i = fix((left+right) / 2);
  if abs(key - table(i))<= tol*abs(key) , found = 1;
  elseif key > table(i), left  = i+1;
  elseif key < table(i), right = i-1;
  else
    fprintf('ERROR (search.m): This cannot happen\n');
  end    
%  disp([key table(i)])
end;

if found           % Find first occurence of key by backwards linear search
  found=0;    
  while i >= 1 & ~found
    if abs(key - table(i)) > tol*abs(key), found = 1;
    else                          i = i - 1;
    end;  
  end
  i=i+1;
else
  i = N+1;         % Search failed
end  
  
 


