function X = testimage(N)
%PCHIMAGE Test image
%
% function X = testimage(N)
%
% Generates the test image from the blur test problem in Reg. Tools.

% Per Christian Hansen, IMM, March 27, 2000.

% Start with an image of all zeros.
x = zeros(N,N);
N2 = round(N/2);
N3= round(N/3);
N6 = round(N/6);
N12 = round(N/12);

% Add a large ellipse.
T = zeros(N6,N3);
for i=1:N6, for j=1:N3
  if ( (i/N6)^2 + (j/N3)^2 < 1 ), T(i,j) = 1; end
end, end
T = [fliplr(T),T];
T = [flipud(T);T];
x(2+[1:2*N6],N3-1+[1:2*N3]) = T;

% Add a smaller ellipse.
T = zeros(N6,N3);
for i=1:N6, for j=1:N3
  if ( (i/N6)^2 + (j/N3)^2 < 0.6 ), T(i,j) = 1; end
end, end
T = [fliplr(T),T];
T = [flipud(T);T];
x(N6+[1:2*N6],N3-1+[1:2*N3]) = x(N6+[1:2*N6],N3-1+[1:2*N3]) + 2*T;
% Correct for overlap.
f = find(x==3);
x(f) = 2*ones(size(f));

% Add a triangle.
T = triu(ones(N3,N3));
[mT,nT] = size(T);
x(N3+N12+[1:nT],1+[1:mT]) = 3*T;

% Add a cross.
T = zeros(2*N6+1,2*N6+1);
[mT,nT] = size(T);
T(N6+1,1:nT) = ones(1,nT);
T(1:mT,N6+1) = ones(mT,1);
x(N2+N12+[1:mT],N2+[1:nT]) = 4*T;

% Make sure x is N-times-N, and stack the columns of x.
X = x(1:N,1:N);
