function [Dxc,Dxxc,replace]=updfdmat(Dxc,Dxxc,x,L,p,ind,added,removed)
%UPDFDMAT  Update operators created by fdmat.m
%
%  [Dx,Dxx,replace]=updfdmat(Dx,Dxx,x,L,p,ind,added,removed)
%
% Input
%
%   Dx, Dxx:  Old operators
%   x:        Abscissae (on finest level)
%   L:        Interval length
%   p:        Stencil
%   ind:      Indices where points are located  (xc=x(ind)) 
%   added:    Indices where points have been added 
%   removed:  Indices where points have been removed
%
% Output
%
%   Dx, Dxx:  New operators (corresp to xc)
%   replace:  Indices where rows have been replaced     
%
%
% See also fdmat, burgerwofd, nlswofd.

% OMN, May 1997

  w = (p-1)/2;             

%  disp([sum(added), sum(removed)])
    
  if any(removed)       % Update operators acc to removed points
    
    indrem = ind & ~added;   % Indices before anything was added
    Nc = sum(indrem);     
    xc = x(find(indrem));
    replace = zeros(Nc,1);   % Rows to be recomputed
    
    r = removed;
    while any(r)
      [M,i] = max(r);        % Find first remaining element
      r(i)=0;
      
      % Determine which rows are to be replaced.
      %
      count = sum(indrem(1:i-1));   % Number of previous elements 
      i1 = pmod(count-w,Nc)+1;   % Allow for width of stencil
      i2 = pmod(count+w-1,Nc)+1;
      if i1 < i2
        replace(i1:i2) = replace(i1:i2) | ones(p-1,1);
      else
        replace(i1:Nc) = replace(i1:Nc) | ones(Nc-i1+1,1);        
        replace(1:i2) = replace(1:i2) | ones(i2,1);
      end;
      	      	
      % Remove row and column corresp to count
      %		
      len=length(Dxxc);    
     % size(Dxxc)  
     % count
      Dxxc = [Dxxc(1:count,:); Dxxc(count+2:len,:)]; %Remove row count+1
      Dxxc = [Dxxc(:,1:count), Dxxc(:,count+2:len)]; %Remove col count+1      
      Dxc = [Dxc(1:count,:); Dxc(count+2:len,:)]; %Remove row count+1
      Dxc = [Dxc(:,1:count), Dxc(:,count+2:len)]; %Remove col count+1      
    end;

    [Bx,Bxx]=fdmat(xc,L,p,replace);   % compute new rows

    for k=1:Nc
      if replace(k)
        Dxc(k,:)  = Bx(k,:);   
        Dxxc(k,:) = Bxx(k,:);         
      end
    end
  end;    

  if any(added)
    indadd = ind;            % Indices are used as is.
    Nc = sum(indadd);     
    replace = zeros(Nc,1);   % Rows to be recomputed
    xc = x(find(indadd));
    a=added;    
    while any(a)
      [M,i] = max(a);        % Find first remaining element
      a(i)=0;
      
      % Determine which rows are to be replaced.
      %
      count = sum(indadd(1:i-1));   % Number of previous elements 
      i1 = pmod(count-w,Nc)+1;   % Allow for width of stencil
      i2 = pmod(count+w,Nc)+1;
      if i1 < i2
        replace(i1:i2) = replace(i1:i2) | ones(p,1);
      else
        replace(i1:Nc) = replace(i1:Nc) | ones(Nc-i1+1,1);        
        replace(1:i2) = replace(1:i2) | ones(i2,1);
      end;
      	      	
      % Add row and column corresp to count
      %		
      len=length(Dxxc);      
      Dxxc = [Dxxc(1:count,:); zeros(1,len); Dxxc(count+1:len,:)]; %Add row count+1
      Dxxc = [Dxxc(:,1:count), zeros(len+1,1), Dxxc(:,count+1:len)]; %Add col count+1      
      Dxc = [Dxc(1:count,:); zeros(1,len); Dxc(count+1:len,:)]; %Add row count+1
      Dxc = [Dxc(:,1:count), zeros(len+1,1), Dxc(:,count+1:len)]; %Add col count+1      
    end;
    
    [Bx,Bxx]=fdmat(xc,L,p,replace);   % compute new rows

    for k=1:Nc
      if replace(k)
        Dxc(k,:)  = Bx(k,:);   
        Dxxc(k,:) = Bxx(k,:);         
      end
    end
    
  end;
    
% For TEST purposes only
%
%  ratio= sum(replace)/length(replace);
%  fprintf('Time     = %16.4f, flops     = %16.4f, ratio = %8.2f\n',t0, f0,ratio)   
%  fprintf('Ref Time = %16.4f, ref flops = %16.4f, *ratio= %8.2f\n',t1, f1,ratio*f1)   









