function wavecompare
%WAVECOMPARE
%
%  wavecompare 
%
%  Demo comparing a Fourier expansion and a wavelet expansion
%


xs = 16;  %Fontsize
fs = 16;  % -"-

m = 1024;
n = 17;          % number of basis functions to be used 
D = 4;           % Wavelet genus
saveplot = 0;    % save to eps-files

%----------
% Sawtooth
%----------
x = (0:m-1)'/m;
y = x .* (x < 0.5) + (x-1) .* (x >= 0.5);

figure(1); plot(x,y)
xlabel('x','Fontsize',[xs])   
%ylabel('f','Fontsize',[xs])   
set(gca,'Ytick',[-0.5 0 0.5]) 
set(gca,'Xtick',[0 1])
set(gca,'Xlim',[0 1])  
set(gca,'Fontsize',[fs])
title('Signal')
if saveplot
  print -depsc2 signal.eps
end;

%%%%%%%%%%%%%%%%%%%%% Approx by n largest fourier terms
ydft = fft(y);
figure(2)
subplot(2,1,1);plot(-m/2+1:m/2,abs(fftshift(ydft)));
set(gca,'Ytick',[0 0.1 0.2 0.3]) 
set(gca,'Xtick',[-512 -256 0 256 512])
set(gca,'Xlim',[-512 512])  
set(gca,'Fontsize',[fs])    

title('Fourier spectrum')
if saveplot    
  print -depsc2 dftspec.eps    
end        
%%%% Take only the n largest basis functions
[csort, isort] = sort(abs(ydft));

ydft_trunc = ydft;
ydft_trunc(isort(1:m-n)) = zeros(m-n,1);    

y2 = ifft(ydft_trunc);
%fprintf('Imag y2: %8.2e\n', norm(imag(y2)/norm(y)));
y2 = real(y2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(2)
subplot(2,1,2);plot(x,y,x,y2,'-')
set(gca,'Ytick',[-0.6 0 0.6]) 
set(gca,'Ylim',[-0.6 0.6])     
set(gca,'Xtick',[0 1])
set(gca,'Xlim',[0 1])  
set(gca,'Fontsize',[fs])    

title('Fourier approximation')
%xlabel('x') 
xlabel('x','Fontsize',[xs])         
if saveplot    
  print -depsc2 dftapp.eps    
end        
fprintf('Error DFT expansion: %8.2e \n', norm(y-y2)/norm(y))
        

%%%%%%%%%%%% Find wavelet coefficients
%    c    = dst(y,D);
%    yfwt = fwt(c,D);
yfwt = fwt(y,D);

figure(3)
subplot(2,1,1);plot(yfwt)
set(gca,'Xtick',[0 64 128 256 512 1024])
set(gca,'Xlim',[0 1024])  
set(gca,'Fontsize',[fs])    
   
title('Wavelet spectrum')
if saveplot
  print -depsc2 wavespec.eps    
end

%%%% Take only the n largest basis functions
[csort, isort] = sort(abs(yfwt));
yfwt_trunc = yfwt;
yfwt_trunc(isort(1:m-n)) = zeros(m-n,1);    


%%%%%%%%%%%%%%%%%%%%%%% Approximate with wavelets
%    c3 = ifwt(yfwt_trunc,D);
%    y3 = idst(c3,D);
y3 = ifwt(yfwt_trunc,D);
figure(3)
subplot(2,1,2);plot(x,y,x,y3,'-')
set(gca,'Ytick',[-0.6 0 0.6]) 
set(gca,'Ylim',[-0.6 0.6])         
set(gca,'Xtick',[0 1])
set(gca,'Xlim',[0 1])  
set(gca,'Fontsize',[fs])    

title('Wavelet approximation')
xlabel('x','Fontsize',[xs])                 
if saveplot    
  print -depsc2 waveapp.eps    
end
            

%%%%%%%%%%%% Plot wavelet decomposition
H=figure(4);
%set(H,'Position',[360 144 560 700])
plotw(x,y,D)
%set(gca,'Ytick',[]) 
set(gca,'Xtick',[0 1])
set(gca,'Xlim',[0 1])  
%set(gca,'Ylim',[-4 38])      
set(gca,'Fontsize',[fs])
%orient tall    

%Take care of children of figure 4
Hc = get(gca,'Children');
for k=1:length(Hc)
  if get(Hc(k),'Type') == 'text'
    set(Hc(k),'Fontsize',[fs])      
  end; 	
end;

title('Wavelet decomposition')

%% Put tilde's over V and W in figure 4
%text(1.0200, 1.5,'~','Fontsize',[fs])     
%text(1.0265, 6.5,'~','Fontsize',[fs])         
%text(1.0265,11.5,'~','Fontsize',[fs])             
%text(1.0265,16.5,'~','Fontsize',[fs])             
%text(1.0265,21.5,'~','Fontsize',[fs])             
%text(1.0265,26.5,'~','Fontsize',[fs])             
%%text(1.0265,31.5,'~','Fontsize',[fs])             
%%text(1.0200,36.5,'~','Fontsize',[fs])             
    
if saveplot    
  print -depsc2 wavedeco.eps
%  print -deps wavedeco.eps
end


fprintf('Error FWT expansion: %8.2e \n', norm(y-y3)/norm(y))


return

figure(7)
tmp = flipud(csort);
plot(tmp(1:50),'*')
title('Sorted wavelet spectrum')
